package com.ruoyi.basic.mapper;

import java.util.List;
import com.ruoyi.basic.domain.HwArea;

/**
 * 区域管理Mapper接口
 * 
 * @author YINQ
 * @date 2023-08-30
 */
public interface HwAreaMapper 
{
    /**
     * 查询区域管理
     * 
     * @param areaId 区域管理主键
     * @return 区域管理
     */
    public HwArea selectHwAreaByAreaId(Long areaId);

    /**
     * 查询区域管理列表
     * 
     * @param hwArea 区域管理
     * @return 区域管理集合
     */
    public List<HwArea> selectHwAreaList(HwArea hwArea);

    /**
     * 新增区域管理
     * 
     * @param hwArea 区域管理
     * @return 结果
     */
    public int insertHwArea(HwArea hwArea);

    /**
     * 修改区域管理
     * 
     * @param hwArea 区域管理
     * @return 结果
     */
    public int updateHwArea(HwArea hwArea);

    /**
     * 删除区域管理
     * 
     * @param areaId 区域管理主键
     * @return 结果
     */
    public int deleteHwAreaByAreaId(Long areaId);

    /**
     * 批量删除区域管理
     * 
     * @param areaIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHwAreaByAreaIds(Long[] areaIds);
}
